manage package
==============

Submodules
----------

manage.auto_import module
-------------------------

.. automodule:: manage.auto_import
    :members:
    :undoc-members:
    :show-inheritance:

manage.cli module
-----------------

.. automodule:: manage.cli
    :members:
    :undoc-members:
    :show-inheritance:

manage.commands_collector module
--------------------------------

.. automodule:: manage.commands_collector
    :members:
    :undoc-members:
    :show-inheritance:

manage.template module
----------------------

.. automodule:: manage.template
    :members:
    :undoc-members:
    :show-inheritance:

manage.utils module
-------------------

.. automodule:: manage.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: manage
    :members:
    :undoc-members:
    :show-inheritance:
